==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x05ab+ 4360-0x16b3));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x0815+ 6486-0x216a));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x0298+ 7210-0x1ec0));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getValueOfSessionShadowingMode{(my $value=shift (@_));if ((
($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ((0x0425+ 3205-0x10aa));}elsif ((($value 
eq $DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue)))
{return ((0x0794+ 5168-0x1bc3));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0f1a+ 444-0x10d4));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0616+  48-0x0645));}return ((0x0871+ 721-0x0b42));}return (
(0x0e27+ 5833-0x24ef));

==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/DesktopMode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::DesktopMode;no warnings;($DesktopMode::ViewOnlyValue=
(0x09a3+ 6410-0x22ad));($DesktopMode::ViewOnlyString=
"\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79");($DesktopMode::RestrictedValue=
(0x00da+ 2490-0x0a93));($DesktopMode::RestrictedString=
"\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64");($DesktopMode::InteractiveValue=
(0x0acf+ 417-0x0c6e));($DesktopMode::InteractiveString=
"\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65");sub getViewOnlyValue{return (
$DesktopMode::ViewOnlyValue);}sub getRestrictedValue{return (
$DesktopMode::RestrictedValue);}sub getInteractiveValue{return (
$DesktopMode::InteractiveValue);}sub convertShadowModeToText{(my $value=shift (
@_));if ((($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ($DesktopMode::ViewOnlyString);}elsif (((
$value eq $DesktopMode::RestrictedString)or ($value eq 
$DesktopMode::RestrictedValue))){return ($DesktopMode::RestrictedString);}elsif 
((($value eq $DesktopMode::InteractiveString)or ($value eq 
$DesktopMode::InteractiveValue))){return ($DesktopMode::InteractiveString);}
Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub getValueOfSessionShadowingMode{(my $value=shift (@_));if ((
($value eq $DesktopMode::ViewOnlyString)or ($value eq 
$DesktopMode::ViewOnlyValue))){return ((0x0c6b+ 3157-0x18c0));}elsif ((($value 
eq $DesktopMode::RestrictedString)or ($value eq $DesktopMode::RestrictedValue)))
{return ((0x0074+ 3832-0x0f6b));}elsif ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0809+ 4520-0x19af));}Logger::error (
"\x4f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x64\x65\x73\x6b\x74\x6f\x70\x20\x6d\x6f\x64\x65\x2e"
);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x43\x6f\x6e\x66\x69\x67\x75\x72\x61\x74\x69\x6f\x6e"
->throw (
"\x6f\x6e\x6c\x79\x20\x74\x68\x65\x20\x66\x6f\x6c\x6c\x6f\x77\x69\x6e\x67\x20\x76\x61\x6c\x75\x65\x73\x3a\x20\x30\x2c\x20\x31\x2c\x20\x32\x2c\x20\x22\x56\x69\x65\x77\x2d\x6f\x6e\x6c\x79\x22\x2c\x20\x22\x52\x65\x73\x74\x72\x69\x63\x74\x65\x64\x22\x2c\x20\x22\x49\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x22\x20\x61\x72\x65\x20\x61\x63\x63\x65\x70\x74\x65\x64\x20\x66\x6f\x72\x20\x27\x53\x65\x73\x73\x69\x6f\x6e\x53\x68\x61\x64\x6f\x77\x4d\x6f\x64\x65\x27\x20\x6b\x65\x79"
);return ((""));}sub isInteractive{(my $value=shift (@_));if ((($value eq 
$DesktopMode::InteractiveString)or ($value eq $DesktopMode::InteractiveValue))){
return ((0x0195+ 9489-0x26a5));}return ((0x03ab+ 7717-0x21d0));}return (
(0x00d7+ 9358-0x2564));
